module.exports = defineTest({
	description: 'passing unbound default export to function cannot rebind it'
});
